@@ -42,7 +42,7 @@ class Retrie:
         """Initialize Trie and set regex config.
 
         Note:
-            Although the Trie is case-sensitive, by defailt re.IGNORECASE is used.
+            Although the Trie is case-sensitive, by default re.IGNORECASE is used.
 
         Args:
             word_boundary (str): Token to wrap the retrie to exclude certain matches.
@@ -54,7 +54,8 @@ class Retrie:
 
     @classmethod
     def parse_re_flags(
-        cls, re_flags,  # type: re_flag_type
+        cls,
+        re_flags,  # type: re_flag_type
     ):  # type: (...) -> int
         return int(re_flags) if re_flags else 0
 
@@ -109,7 +110,7 @@ class Checklist(Retrie):
         """Check and mutate strings against a Retrie.
 
         Note:
-            Although the Trie is case-sensitive, by defailt re.IGNORECASE is used.
+            Although the Trie is case-sensitive, by default re.IGNORECASE is used.
 
         Args:
             keys (Sequence): Strings to build the Retrie from.
@@ -122,8 +123,7 @@ class Checklist(Retrie):
 
         Retrie.__init__(self, word_boundary=word_boundary, re_flags=re_flags)
 
-        for term in keys:
-            self.trie.add(term)
+        self.trie.add(*keys)
 
     @cached_property
     def compiled(self):  # type: (...) -> Pattern[Text]
@@ -154,7 +154,7 @@ class Blacklist(Checklist):
         """Mutate [sequences of] strings based on their match against blacklisted.
 
         Note:
-            Although the Trie is case-sensitive, by defailt re.IGNORECASE is used.
+            Although the Trie is case-sensitive, by default re.IGNORECASE is used.
 
         Args:
             blacklisted (Sequence): Strings to build the Retrie from.
@@ -177,7 +177,8 @@ class Blacklist(Checklist):
         return self.is_listed(term)
 
     def filter(  # noqa:A003
-        self, sequence,  # type: Sequence[Text]
+        self,
+        sequence,  # type: Sequence[Text]
     ):  # type: (...) -> Iterator[Text]
         """Construct an iterator from those elements of sequence not blacklisted."""
         return filter(self.not_listed, sequence)
@@ -200,7 +201,7 @@ class Whitelist(Checklist):
         """Mutate [sequences of] strings based on their match against whitelisted.
 
         Note:
-            Although the Trie is case-sensitive, by defailt re.IGNORECASE is used.
+            Although the Trie is case-sensitive, by default re.IGNORECASE is used.
 
         Args:
             whitelisted (Sequence): Strings to build the Retrie from.
@@ -223,7 +224,8 @@ class Whitelist(Checklist):
         return self.is_listed(term)
 
     def filter(  # noqa:A003
-        self, sequence,  # type: Sequence[Text]
+        self,
+        sequence,  # type: Sequence[Text]
     ):  # type: (...) -> Iterator[Text]
         """Construct an iterator from whitelisted elements of sequence."""
         return filter(self.is_listed, sequence)
@@ -248,7 +250,7 @@ class Replacer(Checklist):
         """Replace occurrences of replacement_mapping.keys() with corresponding values.
 
         Note:
-            Although the Trie is case-sensitive, by defailt re.IGNORECASE is used.
+            Although the Trie is case-sensitive, by default re.IGNORECASE is used.
 
         Args:
             replacement_mapping (Mapping): Mapping {old: new} to replace.
@@ -288,6 +290,6 @@ class Replacer(Checklist):
 
         Args:
             text (str): String to search & replace.
-            count (int): Amount of occurences to replace. If 0 or emitted, replace all.
+            count (int): Amount of occurences to replace. If 0 or omitted, replace all.
         """
         return self.compiled.sub(self._replace, text, count=count)
